@@ -1,22 +1,27 @@
 from ssm_cli.instances import Instances
+from ssm_cli.config import config
 from ssm_cli.commands.base import BaseCommand
-from ssm_cli.cli_args import ARGS
+from dataclasses import dataclass
 
 import logging
 logger = logging.getLogger(__name__)
 
+@dataclass
+class ShellConfig:
+    selector: str = "tui"
 
 class ShellCommand(BaseCommand):
+    CONFIG = ShellConfig
     HELP = "Connects to instances"
     
     def add_arguments(parser):
         parser.add_argument("group", type=str, help="group to run against")
 
-    def run():
+    def run(args, session):
         logger.info("running shell action")
 
-        instances = Instances()
-        instance = instances.select_instance(ARGS.group, "tui")
+        instances = Instances(session)
+        instance = instances.select_instance(args.group, "tui")
 
         if instance is None:
             logger.error("failed to select host")
@@ -24,4 +29,4 @@ class ShellCommand(BaseCommand):
 
         logger.info(f"connecting to {repr(instance)}")
         
-        instance.start_session()
\ No newline at end of file
+        instance.start_session(session)
\ No newline at end of file
