@@ -1,7 +1,6 @@
 from typing import Dict
 from confclasses import confclass
 
-# See cli_args for more info but this needs a rethink to be easier to use/add to
 
 @confclass
 class ProxyCommandConfig:
@@ -25,5 +24,5 @@ class Config:
     actions: ActionsConfig
     group_tag_key: str = "group"
     """Tag key to use when filtering, this is usually set during ssm setup."""
-
-CONFIG = Config()
+    
+config = Config()
