@@ -1,10 +1,7 @@
+# All XDG path logic here
 from pathlib import Path
-from xdg_base_dirs import xdg_config_home, xdg_state_home
+from xdg_base_dirs import xdg_config_home
 
-# Default locations for ssm-cli files
-# ~/.config/ssm-cli/ssm.yaml
-# ~/.config/ssm-cli/hostkey.pem
-# ~/.local/state/ssm-cli/ssm.log
 
 def get_conf_root(check=True) -> Path:
     root = xdg_config_home() / 'ssm-cli'
@@ -13,12 +10,6 @@ def get_conf_root(check=True) -> Path:
         create_conf_dir()
     return root
 
-def get_state_root() -> Path:
-    path = xdg_state_home() / 'ssm-cli'
-    if not path.exists():
-        path.mkdir(parents=True)
-    return path
-
 def get_conf_file(check=True) -> Path:
     path = get_conf_root(check) / 'ssm.yaml'
     if check and not path.exists():
@@ -26,7 +17,7 @@ def get_conf_file(check=True) -> Path:
     return path
 
 def get_log_file(check=False) -> Path:
-    path = get_state_root() / 'run.log'
+    path = get_conf_root(True) / 'ssm.log'
     if check and not path.exists():
         raise EnvironmentError(f"{path} missing, run `ssm setup` to create")
     return path
